declare module BA.Ui {
    /**
     * Class to show toast notifications
     */
    class Toast {
        /**
         * Initialize the toast with some default values
         */
        static Initialize(): void;
        /**
         * Shows a blue info toast
         *
         * @param message Message to display in toast
         * @param title Title to display on toast
         * @param overrides Option values for toast
         * @param oid Oid will be the toast's ID in html code
         */
        static Info(message: string, title?: string, overrides?: ToastrOptions, oid?: BA.Classes.Guid): BA.Classes.Guid;
        /**
         * Shows a static blue info toast
         *
         * @param message Message to display in toast
         * @param title Title to display on toast
         * @param oid Oid will be the toast's ID in html code
         */
        static InfoSticky(message: string, title?: string, oid?: BA.Classes.Guid): BA.Classes.Guid;
        /**
         * Shows a green success toast
         *
         * @param message Message to display in toast
         * @param title Title to display on toast
         * @param overrides Option values for toast
         * @param oid Oid will be the toast's ID in html code
         */
        static Success(message: string, title?: string, overrides?: ToastrOptions, oid?: BA.Classes.Guid): BA.Classes.Guid;
        /**
         * Shows a static green success toast
         *
         * @param message Message to display in toast
         * @param title Title to display on toast
         * @param oid Oid will be the toast's ID in html code
         */
        static SuccessSticky(message: string, title?: string, oid?: BA.Classes.Guid): BA.Classes.Guid;
        /**
         * Shows a yellow warning toast
         *
         * @param message Message to display in toast
         * @param title Title to display on toast
         * @param overrides Option values for toast. If null, the toast will be visible for 15 seconds
         * @param oid Oid will be the toast's ID in html code
         */
        static Warning(message: string, title?: string, overrides?: ToastrOptions, oid?: BA.Classes.Guid): BA.Classes.Guid;
        /**
         * Shows a static yellow warning toast
         *
         * @param message Message to display in toast
         * @param title Title to display on toast
         * @param oid Oid will be the toast's ID in html code
         */
        static WarningSticky(message: string, title?: string, oid?: BA.Classes.Guid): BA.Classes.Guid;
        /**
         * Shows a red error toast
         *
         * @param message Message to display in toast
         * @param title Title to display on toast
         * @param overrides Option values for toast. If null, the toast will be visible for 30 seconds
         * @param oid Oid will be the toast's ID in html code
         */
        static Error(message: string, title?: string, overrides?: ToastrOptions, oid?: BA.Classes.Guid): BA.Classes.Guid;
        /**
         * Shows a static red error toast
         *
         * @param message Message to display in toast
         * @param title Title to display on toast
         * @param oid Oid will be the toast's ID in html code
         */
        static ErrorSticky(message: string, title?: string, oid?: BA.Classes.Guid): BA.Classes.Guid;
        /**
         * Hides the toaster with the given id.
         * @param oid Id of the toaster to hide
         */
        static HideToast(oid: BA.Classes.Guid): void;
        private static InjectOid;
        private static TryUpdateExistingToast;
    }
}
